package org.apache.bcel.util;

import java.io.IOException;
import java.io.InputStream;
import org.apache.bcel.classfile.ClassParser;
import org.apache.bcel.classfile.JavaClass;
import org.apache.bcel.classfile.Utility;

abstract class AbstractClassPathRepository implements Repository {
   private final ClassPath classPath;

   AbstractClassPathRepository(ClassPath classPath) {
      this.classPath = classPath;
   }

   public abstract void clear();

   public abstract JavaClass findClass(String var1);

   public ClassPath getClassPath() {
      return this.classPath;
   }

   public JavaClass loadClass(Class<?> clazz) throws ClassNotFoundException {
      String className = clazz.getName();
      JavaClass repositoryClass = this.findClass(className);
      if (repositoryClass != null) {
         return repositoryClass;
      } else {
         String name = className;
         int i = name.lastIndexOf(46);
         if (i > 0) {
            name = name.substring(i + 1);
         }

         try {
            InputStream clsStream = clazz.getResourceAsStream(name + ".class");
            Throwable var7 = null;

            JavaClass var8;
            try {
               var8 = this.loadClass(clsStream, className);
            } catch (Throwable var18) {
               var7 = var18;
               throw var18;
            } finally {
               if (clsStream != null) {
                  if (var7 != null) {
                     try {
                        clsStream.close();
                     } catch (Throwable var17) {
                        var7.addSuppressed(var17);
                     }
                  } else {
                     clsStream.close();
                  }
               }

            }

            return var8;
         } catch (IOException var20) {
            return null;
         }
      }
   }

   private JavaClass loadClass(InputStream inputStream, String className) throws ClassNotFoundException {
      try {
         if (inputStream != null) {
            ClassParser parser = new ClassParser(inputStream, className);
            JavaClass clazz = parser.parse();
            this.storeClass(clazz);
            return clazz;
         }
      } catch (IOException var5) {
         IOException e = var5;
         throw new ClassNotFoundException("Exception while looking for class " + className + ": " + e, e);
      }

      throw new ClassNotFoundException("ClassRepository could not load " + className);
   }

   public JavaClass loadClass(String className) throws ClassNotFoundException {
      if (className != null && !className.isEmpty()) {
         className = Utility.pathToPackage(className);
         JavaClass clazz = this.findClass(className);
         if (clazz != null) {
            return clazz;
         } else {
            try {
               InputStream inputStream = this.classPath.getInputStream(className);
               Throwable var4 = null;

               JavaClass var5;
               try {
                  var5 = this.loadClass(inputStream, className);
               } catch (Throwable var15) {
                  var4 = var15;
                  throw var15;
               } finally {
                  if (inputStream != null) {
                     if (var4 != null) {
                        try {
                           inputStream.close();
                        } catch (Throwable var14) {
                           var4.addSuppressed(var14);
                        }
                     } else {
                        inputStream.close();
                     }
                  }

               }

               return var5;
            } catch (IOException var17) {
               IOException e = var17;
               throw new ClassNotFoundException("Exception while looking for class " + className + ": " + e, e);
            }
         }
      } else {
         throw new IllegalArgumentException("Invalid class name " + className);
      }
   }

   public abstract void removeClass(JavaClass var1);

   public abstract void storeClass(JavaClass var1);
}
